@@ -11,7 +11,7 @@ import javax.media.j3d.*;
  * などの機能を提供するメソッドが定義されています。
  */
 public abstract class A3Object {
-    static BoundingSphere bs = new BoundingSphere(new Point3d(0.0,0.0,0.0),10.0);
+    static BoundingSphere bs = new BoundingSphere(new Point3d(0.0,0.0,0.0),Double.MAX_VALUE);
 //    protected static final Serializable NULL = A23.NULL;
 
 
@@ -533,7 +533,6 @@ public abstract class A3Object {
     /**
      * Behaviorが有効である時A3Objectの現在のスピードを返します。
      * Behaviorが無効である場合は常に0を返します。
-     * @return
      */
     public final double getSpeed() {
         return behavior.getSpeed();
