@@ -51,8 +51,8 @@ class A3VirtualUniverse extends VirtualUniverse {
         view.addCanvas3D(canvas3d);
         view.setPhysicalBody(body);
         view.setPhysicalEnvironment(environment);
-//        view.setFrontClipDistance(0.001);
-        view.setBackClipDistance(1000.0);
+        view.setFrontClipDistance(0.1);
+        view.setBackClipDistance(100.0);
         view.setUserHeadToVworldEnable(true);
 
         vpGroup = new BranchGroup();
@@ -64,7 +64,7 @@ class A3VirtualUniverse extends VirtualUniverse {
         tGroup.setTransform(transform);
         timerBehavior = new TimerBehavior();
         BoundingSphere bs = new BoundingSphere(new Point3d(0.0,0.0,0.0),
-                                               10.0);
+                                               Double.MAX_VALUE);
         timerBehavior.setSchedulingBounds(bs);
         tGroup.addChild(timerBehavior);
         vp = new ViewPlatform();
@@ -72,7 +72,7 @@ class A3VirtualUniverse extends VirtualUniverse {
         tGroup.addChild(vp);
         headLight = new DirectionalLight();
         headLight.setCapability(Light.ALLOW_STATE_WRITE);
-        headLight.setInfluencingBounds(new BoundingSphere(new Point3d(0.0,0.0,0.0),100.0));
+        headLight.setInfluencingBounds(new BoundingSphere(new Point3d(0.0,0.0,0.0),Double.MAX_VALUE));
         headLight.setEnable(true);
         tGroup.addChild(headLight);
 
@@ -85,7 +85,7 @@ class A3VirtualUniverse extends VirtualUniverse {
 
         pickingBehavior = new PickingBehavior(this,view,tGroup,locale);
         vpGroup.addChild(pickingBehavior);
-        BoundingSphere sb = new BoundingSphere(new Point3d(0.0,0.0,0.0),10.0);
+        BoundingSphere sb = new BoundingSphere(new Point3d(0.0,0.0,0.0),Double.MAX_VALUE);
         pickingBehavior.setSchedulingBounds(sb);
         cameraBehavior = new CameraBehavior(this);
         vpGroup.addChild(cameraBehavior);
