@@ -71,7 +71,7 @@ class Action3DData {
     BranchGroup allActionBranchGroup;
     //Switch allActionSwitch;
 
-    static BoundingSphere bounding = new BoundingSphere(new Point3d(0.0,0.0,0.0),100.0);
+    static BoundingSphere bounding = new BoundingSphere(new Point3d(0.0,0.0,0.0),Double.MAX_VALUE);
     //アクションの中のパーツのデータを保存しておくためのクラス
     class Part {
         String fileName;
